@@ -75,7 +75,7 @@ extern "C" {
    To avoid the atexit workaround, #define GLUT_DISABLE_ATEXIT_HACK. */
 
 /* XXX This is from Win32's <process.h> */
-# if !defined(_MSC_VER) && !defined(__cdecl)
+# if !defined(_MSC_VER) && !defined(__MINGW32__) && !defined(__cdecl)
    /* Define __cdecl for non-Microsoft compilers. */
 #  define __cdecl
 #  define GLUT_DEFINED___CDECL
@@ -108,7 +108,7 @@ extern _CRTIMP void __cdecl exit(int);
    and redifinition of Windows system defs, also removes requirement of
    pretty much any standard windows header from this file */
 
-#if (_MSC_VER >= 800) || defined(_STDCALL_SUPPORTED) || defined(__CYGWIN32__)
+#if (_MSC_VER >= 800) || defined(__MINGW32__) || defined(_STDCALL_SUPPORTED) || defined(__CYGWIN32__)
 #	define GLUTAPIENTRY __stdcall
 #else
 #	define GLUTAPIENTRY
@@ -223,9 +223,11 @@ WGLAPI int   GLAPIENTRY SetPixelFormat(HDC,int,const PIXELFORMATDESCRIPTOR *);
  video resize subAPI, glutPostWindowRedisplay, glutKeyboardUpFunc,
  glutSpecialUpFunc, glutIgnoreKeyRepeat, glutSetKeyRepeat,
  glutJoystickFunc, glutForceJoystickFunc (NOT FINALIZED!).
+
+ GLUT_API_VERSION=5  glutGetProcAddress (added by BrianP)
 **/
 #ifndef GLUT_API_VERSION  /* allow this to be overriden */
-#define GLUT_API_VERSION		3
+#define GLUT_API_VERSION		5
 #endif
 
 /**
@@ -348,7 +350,7 @@ WGLAPI int   GLAPIENTRY SetPixelFormat(HDC,int,const PIXELFORMATDESCRIPTOR *);
 #define GLUT_NORMAL			0
 #define GLUT_OVERLAY			1
 
-#if defined(_WIN32)
+#if defined(_WIN32) || defined (GLUT_IMPORT_LIB)
 /* Stroke font constants (use these in GLUT program). */
 #define GLUT_STROKE_ROMAN		((void*)0)
 #define GLUT_STROKE_MONO_ROMAN		((void*)1)
@@ -646,7 +648,7 @@ GLUTAPI void GLUTAPIENTRY glutJoystickFunc(void (GLUTCALLBACK *func)(unsigned in
 #endif
 
 /* GLUT color index sub-API. */
-GLUTAPI void GLUTAPIENTRY glutSetColor(int, GLfloat red, GLfloat green, GLfloat blue);
+GLUTAPI void GLUTAPIENTRY glutSetColor(int ndx, GLfloat red, GLfloat green, GLfloat blue);
 GLUTAPI GLfloat GLUTAPIENTRY glutGetColor(int ndx, int component);
 GLUTAPI void GLUTAPIENTRY glutCopyColormap(int win);
 
@@ -661,6 +663,10 @@ GLUTAPI int GLUTAPIENTRY glutExtensionSupported(const char *name);
 GLUTAPI int GLUTAPIENTRY glutGetModifiers(void);
 GLUTAPI int GLUTAPIENTRY glutLayerGet(GLenum type);
 #endif
+#if (GLUT_API_VERSION >= 5)
+typedef void (*GLUTproc)();
+GLUTAPI GLUTproc GLUTAPIENTRY glutGetProcAddress(const char *procName);
+#endif
 
 /* GLUT font sub-API */
 GLUTAPI void GLUTAPIENTRY glutBitmapCharacter(void *font, int character);
